@@ -1,5 +1,5 @@
 //  SPDX-License-Identifier: LGPL-2.1-or-later
-//  Copyright (c) 2015-2024 MariaDB Corporation Ab
+//  Copyright (c) 2015-2025 MariaDB Corporation Ab
 
 'use strict';
 
@@ -10,12 +10,10 @@ const assert = require('chai').assert;
 describe('Connection meta', function () {
   it('server version', () => {
     const serverVersion = shareConn.serverVersion();
-    if (process.env.srv) {
-      if (!isMaxscale()) {
-        const version = process.env.v;
-        if (version && !version.includes('-rc')) {
-          assert(serverVersion.startsWith(version), serverVersion + '/' + version);
-        }
+    if (!isMaxscale()) {
+      const version = process.env.DB_VERSION;
+      if (version && !version.includes('-rc')) {
+        assert(serverVersion.startsWith(version), serverVersion + '/' + version);
       }
     }
   });
@@ -34,8 +32,8 @@ describe('Connection meta', function () {
 
   it('isMariaDB', () => {
     const isMariadb = shareConn.info.isMariaDB();
-    if (process.env.srv) {
-      assert.equal(isMariadb, !process.env.srv.startsWith('mysql'));
+    if (process.env.DB_TYPE) {
+      assert.equal(isMariadb, !process.env.DB_TYPE.startsWith('mysql'));
     }
   });
 
