@@ -1,16 +1,16 @@
 //  SPDX-License-Identifier: LGPL-2.1-or-later
-//  Copyright (c) 2015-2023 MariaDB Corporation Ab
+//  Copyright (c) 2015-2025 MariaDB Corporation Ab
 
 'use strict';
 
 const base = require('../base.js');
 const { assert } = require('chai');
 const Conf = require('../conf');
-const { isXpand } = require('../base');
+const { isMaxscale } = require('../base');
 
 describe('Pool callback', () => {
   before(function () {
-    if (process.env.srv === 'maxscale' || process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
+    if (isMaxscale()) this.skip();
   });
 
   it('pool with wrong authentication', function (done) {
@@ -54,7 +54,6 @@ describe('Pool callback', () => {
   });
 
   it('pool query stack trace', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     const pool = base.createPoolCallback({
       metaAsArray: true,
       multipleStatements: true,
@@ -73,7 +72,6 @@ describe('Pool callback', () => {
   });
 
   it('pool execute stack trace', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     const pool = base.createPoolCallback({
       metaAsArray: true,
       multipleStatements: true,
@@ -93,7 +91,6 @@ describe('Pool callback', () => {
 
   it('pool execute wrong param stack trace', function (done) {
     this.timeout(20000);
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     const pool = base.createPoolCallback({
       metaAsArray: true,
       multipleStatements: true,
@@ -112,7 +109,6 @@ describe('Pool callback', () => {
   });
 
   it('pool batch stack trace', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     const pool = base.createPoolCallback({
       metaAsArray: true,
       multipleStatements: true,
@@ -131,7 +127,6 @@ describe('Pool callback', () => {
   });
 
   it('pool batch wrong param stack trace', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     const pool = base.createPoolCallback({
       metaAsArray: true,
       multipleStatements: true,
@@ -152,25 +147,27 @@ describe('Pool callback', () => {
   });
 
   it('pool error event', async function () {
-    if (process.env.srv === 'maxscale' || process.env.srv === 'skysql-ha') this.skip(); //to avoid host being blocked
+    if (isMaxscale()) this.skip(); //to avoid host being blocked
     this.timeout(10000);
     const pool = base.createPoolCallback({
       acquireTimeout: 4000,
       initializationTimeout: 2000,
+      allowPublicKeyRetrieval: true,
       user: 'wrongAuthentication'
     });
 
     await new Promise(function (resolver, rejecter) {
       pool.on('error', (err) => {
-        assert.isTrue(err.message.includes('Error during pool initialization:'));
+        assert.isTrue(err.message.includes('Error during pool initialization'));
+        assert.isNotNull(err.cause);
         assert.isTrue(
-          err.errno === 1524 ||
-            err.errno === 1045 ||
-            err.errno === 1698 ||
-            err.errno === 45028 ||
-            err.errno === 45025 ||
-            err.errno === 45044,
-          err.message
+          err.cause.errno === 1524 ||
+            err.cause.errno === 1045 ||
+            err.cause.errno === 1698 ||
+            err.cause.errno === 45028 ||
+            err.cause.errno === 45025 ||
+            err.cause.errno === 45044,
+          err.cause.message
         );
         pool.end();
         resolver();
@@ -179,7 +176,7 @@ describe('Pool callback', () => {
   });
 
   it('pool error fail connection', async function () {
-    if (process.env.srv === 'maxscale' || process.env.srv === 'skysql-ha') this.skip(); //to avoid host being blocked
+    if (isMaxscale()) this.skip(); //to avoid host being blocked
     this.timeout(10000);
     const initTime = Date.now();
     const pool = base.createPoolCallback({
@@ -191,7 +188,7 @@ describe('Pool callback', () => {
     await new Promise(function (resolver, rejecter) {
       pool.on('error', (err) => {
         assert(Date.now() - initTime >= 1980, 'expected > 2s, but was ' + (Date.now() - initTime));
-        assert.isTrue(err.message.includes('Error during pool initialization:'));
+        assert.isTrue(err.message.includes('Error during pool initialization'));
         pool.end();
         resolver();
       });
@@ -237,7 +234,6 @@ describe('Pool callback', () => {
   });
 
   it('create pool', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     this.timeout(5000);
     const pool = base.createPoolCallback({ connectionLimit: 1 });
     const initTime = Date.now();
@@ -268,7 +264,6 @@ describe('Pool callback', () => {
   });
 
   it('create pool with noControlAfterUse', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     this.timeout(5000);
     const pool = base.createPoolCallback({
       connectionLimit: 1,
@@ -304,10 +299,8 @@ describe('Pool callback', () => {
         );
         assert.equal(err.sqlState, 'HY000');
       } else {
-        if (!isXpand()) {
-          assert(err.message.includes('You have an error in your SQL syntax'));
-          assert.equal(err.sqlState, '42000');
-        }
+        assert(err.message.includes('You have an error in your SQL syntax'));
+        assert.equal(err.sqlState, '42000');
         assert.equal(err.code, 'ER_PARSE_ERROR');
       }
       pool.end((err) => {
@@ -394,7 +387,6 @@ describe('Pool callback', () => {
   });
 
   it('pool getConnection timeout', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha' || isXpand()) this.skip();
     const pool = base.createPoolCallback({
       connectionLimit: 1,
       acquireTimeout: 200
@@ -427,7 +419,7 @@ describe('Pool callback', () => {
     }
 
     pool.getConnection((err) => {
-      assert(err.message.includes('retrieve connection from pool timeout'));
+      assert(err.message.includes('pool timeout: failed to retrieve a connection from pool after'));
       assert.equal(err.sqlState, 'HY000');
       assert.equal(err.errno, 45028);
       assert.equal(err.code, 'ER_GET_CONNECTION_TIMEOUT');
@@ -436,7 +428,6 @@ describe('Pool callback', () => {
   });
 
   it('pool query timeout', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha' || isXpand()) this.skip();
     this.timeout(10000);
     let errorNo = 0;
     const pool = base.createPoolCallback({
@@ -454,36 +445,35 @@ describe('Pool callback', () => {
       });
     });
     pool.query('SELECT 1', (err, res) => {
-      assert(err.message.includes('retrieve connection from pool timeout'));
+      assert(err.message.includes('pool timeout: failed to retrieve a connection from pool after'));
       assert.equal(err.sqlState, 'HY000');
       assert.equal(err.errno, 45028);
       assert.equal(err.code, 'ER_GET_CONNECTION_TIMEOUT');
       errorNo += 1;
     });
     pool.query('SELECT 2', (err) => {
-      assert(err.message.includes('retrieve connection from pool timeout'));
+      assert(err.message.includes('pool timeout: failed to retrieve a connection from pool after'));
       assert.equal(err.sqlState, 'HY000');
       assert.equal(err.errno, 45028);
       assert.equal(err.code, 'ER_GET_CONNECTION_TIMEOUT');
       const elapse = Date.now() - initTime;
-      assert.isOk(elapse >= 499 && elapse < 550, 'elapse time was ' + elapse + ' but must be just after 500');
+      assert.isOk(elapse >= 475 && elapse < 650, 'elapse time was ' + elapse + ' but must be just after 500');
       errorNo += 1;
     });
     setTimeout(() => {
       pool.query('SELECT 3', (err) => {
-        assert(err.message.includes('retrieve connection from pool timeout'));
+        assert(err.message.includes('pool timeout: failed to retrieve a connection from pool after'));
         assert.equal(err.sqlState, 'HY000');
         assert.equal(err.errno, 45028);
         assert.equal(err.code, 'ER_GET_CONNECTION_TIMEOUT');
         const elapse = Date.now() - initTime;
-        assert.isOk(elapse >= 698 && elapse < 750, 'elapse time was ' + elapse + ' but must be just after 700');
+        assert.isOk(elapse >= 675 && elapse < 850, 'elapse time was ' + elapse + ' but must be just after 700');
         errorNo += 1;
       });
     }, 200);
   });
 
   it('pool direct execute', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     const pool = base.createPoolCallback({ connectionLimit: 1 });
     pool.execute('SELECT ? as a', [2], (err, res, meta) => {
       if (err) return done(err);
@@ -541,13 +531,14 @@ describe('Pool callback', () => {
           assert.equal(pool.activeConnections(), 10);
           assert.equal(pool.totalConnections(), 10);
           assert.equal(pool.idleConnections(), 0);
-          assert.isOk(pool.taskQueueSize() > 9950);
+          console.log(pool.taskQueueSize());
+          assert.isOk(pool.taskQueueSize() > 9800);
         }
 
         setTimeout(() => {
           closed = true;
           pool.end(() => {
-            if (Conf.baseConfig.host === 'localhost' && !isXpand()) {
+            if (Conf.baseConfig.host === 'localhost') {
               assert.equal(pool.activeConnections(), 0);
               assert.equal(pool.totalConnections(), 0);
               assert.equal(pool.idleConnections(), 0);
@@ -585,7 +576,7 @@ describe('Pool callback', () => {
           assert.equal(pool.taskQueueSize(), 0);
 
           conn.query('KILL CONNECTION_ID()', (err) => {
-            assert.equal(err.sqlState, isXpand() ? 'HY000' : '70100');
+            assert.equal(err.sqlState, '70100');
             assert.equal(pool.activeConnections(), 1);
             assert.equal(pool.totalConnections(), 2);
             assert.equal(pool.idleConnections(), 1);
@@ -616,7 +607,7 @@ describe('Pool callback', () => {
       assert.equal(pool.taskQueueSize(), 0);
 
       pool.query('KILL CONNECTION_ID()', (err) => {
-        assert.equal(err.sqlState, isXpand() ? 'HY000' : '70100');
+        assert.equal(err.sqlState, '70100');
         setImmediate(() => {
           assert.equal(pool.taskQueueSize(), 0);
 
@@ -641,7 +632,6 @@ describe('Pool callback', () => {
   });
 
   it('connection end', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     const pool = base.createPoolCallback({ connectionLimit: 2 });
     setTimeout(() => {
       //check available connections in pool
@@ -778,7 +768,23 @@ describe('Pool callback', () => {
             if (err) {
               done(err);
             } else {
-              assert.equal(res.affectedRows, 2);
+              if (res.affectedRows) {
+                assert.equal(res.affectedRows, 2);
+              } else {
+                assert.deepEqual(res, [
+                  {
+                    affectedRows: 1,
+                    insertId: 0n,
+                    warningStatus: 0
+                  },
+                  {
+                    affectedRows: 1,
+                    insertId: 0n,
+                    warningStatus: 0
+                  }
+                ]);
+              }
+
               pool.query('select * from `parse`', (err2, res2) => {
                 assert.deepEqual(res2, [
                   {
@@ -868,7 +874,6 @@ describe('Pool callback', () => {
   });
 
   it('test minimum idle decrease', function (done) {
-    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
     this.timeout(30000);
     const pool = base.createPoolCallback({
       connectionLimit: 10,
@@ -926,10 +931,10 @@ describe('Pool callback', () => {
     const pool = base.createPoolCallback({});
     pool.getConnection((err, conn) => {
       if (err) {
-        assert(err.message.includes('Cannot add request to pool, pool is closed'));
+        assert(err.message.includes('pool is ending, connection request aborted'));
         assert.equal(err.sqlState, 'HY000');
-        assert.equal(err.errno, 45027);
-        assert.equal(err.code, 'ER_POOL_ALREADY_CLOSED');
+        assert.equal(err.errno, 45037);
+        assert.equal(err.code, 'ER_CLOSING_POOL');
         done();
       } else {
         done(new Error('must have thrown an Exception'));
@@ -939,7 +944,7 @@ describe('Pool callback', () => {
   });
 
   it('pool execute timeout', function (done) {
-    if (process.env.srv === 'maxscale' || process.env.srv === 'skysql-ha') this.skip(); //to avoid host being blocked
+    if (isMaxscale()) this.skip(); //to avoid host being blocked
     this.timeout(10000);
     const pool = base.createPoolCallback({
       connectionLimit: 1,
@@ -951,7 +956,7 @@ describe('Pool callback', () => {
       pool.end();
       assert.isTrue(pool.closed);
       if (err) {
-        assert.isTrue(err.message.includes('retrieve connection from pool timeout'));
+        assert.isTrue(err.message.includes('pool timeout: failed to retrieve a connection from pool after'));
         done();
       } else {
         done(new Error('must have thrown error'));
@@ -960,7 +965,7 @@ describe('Pool callback', () => {
   });
 
   it('pool batch timeout', function (done) {
-    if (process.env.srv === 'maxscale' || process.env.srv === 'skysql-ha') this.skip(); //to avoid host being blocked
+    if (isMaxscale()) this.skip(); //to avoid host being blocked
     this.timeout(10000);
     const pool = base.createPoolCallback({
       connectionLimit: 1,
@@ -970,7 +975,7 @@ describe('Pool callback', () => {
     pool.batch('SELECT ?', [[1]], (err, res) => {
       pool.end();
       if (err) {
-        assert.isTrue(err.message.includes('retrieve connection from pool timeout'));
+        assert.isTrue(err.message.includes('pool timeout: failed to retrieve a connection from pool after'));
         done();
       } else {
         done(new Error('must have thrown error'));
@@ -991,4 +996,28 @@ describe('Pool callback', () => {
     });
     pool.end();
   });
+  it('pool.toString', function (done) {
+    const pool = base.createPoolCallback({
+      connectionLimit: 1
+    });
+    pool.query('DO 1', () => {
+      assert.equal('poolCallback(active=0 idle=1 limit=1)', pool.toString());
+      pool.end();
+      done();
+    });
+  });
+
+  it('direct execution without cache', (done) => {
+    const pool = base.createPoolCallback({
+      connectionLimit: 1,
+      acquireTimeout: 400
+    });
+    pool.execute('select ? as a', [2], (err, res, meta) => {
+      if (err) return done(err);
+      assert.isTrue(res[0].a === 2 || res[0].a === 2n);
+      assert.isTrue(meta.length === 1);
+      pool.end();
+      done();
+    });
+  });
 });
